@@ -1,6 +1,3 @@
-/*	$OpenBSD: aux.c,v 1.4 1996/06/08 19:48:10 christos Exp $	*/
-/*	$NetBSD: aux.c,v 1.4 1996/06/08 19:48:10 christos Exp $	*/
-
 /*
  * Copyright (c) 1980, 1993
  *	The Regents of the University of California.  All rights reserved.
@@ -35,11 +32,7 @@
  */
 
 #ifndef lint
-#if 0
 static char sccsid[] = "@(#)aux.c	8.1 (Berkeley) 6/6/93";
-#else
-static char rcsid[] = "$OpenBSD: aux.c,v 1.4 1996/06/08 19:48:10 christos Exp $";
-#endif
 #endif /* not lint */
 
 #include "rcv.h"
@@ -50,7 +43,6 @@ static char rcsid[] = "$OpenBSD: aux.c,v 1.4 1996/06/08 19:48:10 christos Exp $"
  *
  * Auxiliary functions.
  */
-static char *save2str __P((char *, char *));
 
 /*
  * Return a pointer to a dynamic copy of the argument.
@@ -70,7 +62,7 @@ savestr(str)
 /*
  * Make a copy of new argument incorporating old one.
  */
-static char *
+char *
 save2str(str, old)
 	char *str, *old;
 {
@@ -88,6 +80,10 @@ save2str(str, old)
 	return new;
 }
 
+#if (BSD == 43)
+#define vfprintf(stream,fmt,args) _doprnt(fmt,args,stream)
+#endif
+
 /*
  * Announce a fatal error and die.
  */
@@ -187,7 +183,7 @@ hfield(field, mp)
 	while (lc > 0) {
 		if ((lc = gethfield(ibuf, linebuf, lc, &colon)) < 0)
 			return oldhfield;
-		if ((hfield = ishfield(linebuf, colon, field)) != NULL)
+		if (hfield = ishfield(linebuf, colon, field))
 			oldhfield = save2str(hfield, oldhfield);
 	}
 	return oldhfield;
@@ -311,10 +307,9 @@ struct sstack {
  * that they are no longer reading from a tty (in all probability).
  */
 int
-source(v)
-	void *v;
+source(arglist)
+	char **arglist;
 {
-	char **arglist = v;
 	FILE *fi;
 	char *cp;
 
@@ -414,7 +409,7 @@ nameof(mp, reptype)
 	cp = skin(name1(mp, reptype));
 	if (reptype != 0 || charcount(cp, '!') < 2)
 		return(cp);
-	cp2 = rindex(cp, '!');
+	cp2 = strrchr(cp, '!');
 	cp2--;
 	while (cp2 > cp && *cp2 != '!')
 		cp2--;
@@ -466,13 +461,13 @@ skin(name)
 
 	if (name == NOSTR)
 		return(NOSTR);
-	if (index(name, '(') == NOSTR && index(name, '<') == NOSTR
-	    && index(name, ' ') == NOSTR)
+	if (strchr(name, '(') == NOSTR && strchr(name, '<') == NOSTR
+	    && strchr(name, ' ') == NOSTR)
 		return(name);
 	gotlt = 0;
 	lastsp = 0;
 	bufend = nbuf;
-	for (cp = name, cp2 = bufend; (c = *cp++) != '\0'; ) {
+	for (cp = name, cp2 = bufend; c = *cp++; ) {
 		switch (c) {
 		case '(':
 			cp = skip_comment(cp);
@@ -484,13 +479,13 @@ skin(name)
 			 * Start of a "quoted-string".
 			 * Copy it in its entirety.
 			 */
-			while ((c = *cp) != '\0') {
+			while (c = *cp) {
 				cp++;
 				if (c == '"')
 					break;
 				if (c != '\\')
 					*cp2++ = c;
-				else if ((c = *cp) != '\0') {
+				else if (c = *cp) {
 					*cp2++ = c;
 					cp++;
 				}
@@ -522,7 +517,7 @@ skin(name)
 					if (c == '(')
 						cp = skip_comment(cp);
 					else if (c == '"')
-						while ((c = *cp) != '\0') {
+						while (c = *cp) {
 							cp++;
 							if (c == '"')
 								break;
@@ -538,7 +533,9 @@ skin(name)
 		default:
 			if (lastsp) {
 				lastsp = 0;
-				*cp2++ = ' ';
+				/* usernames don't start with a space */
+				if (cp2 > nbuf)
+					*cp2++ = ' ';
 			}
 			*cp2++ = c;
 			if (c == ',' && !gotlt) {
@@ -592,24 +589,24 @@ newname:
 	*cp2 = '\0';
 	if (readline(ibuf, linebuf, LINESIZE) < 0)
 		return(savestr(namebuf));
-	if ((cp = index(linebuf, 'F')) == NULL)
+	if ((cp = strchr(linebuf, 'F')) == NULL)
 		return(savestr(namebuf));
 	if (strncmp(cp, "From", 4) != 0)
 		return(savestr(namebuf));
-	while ((cp = index(cp, 'r')) != NULL) {
+	while ((cp = strchr(cp, 'r')) != NULL) {
 		if (strncmp(cp, "remote", 6) == 0) {
-			if ((cp = index(cp, 'f')) == NULL)
+			if ((cp = strchr(cp, 'f')) == NULL)
 				break;
 			if (strncmp(cp, "from", 4) != 0)
 				break;
-			if ((cp = index(cp, ' ')) == NULL)
+			if ((cp = strchr(cp, ' ')) == NULL)
 				break;
 			cp++;
 			if (first) {
 				strcpy(namebuf, cp);
 				first = 0;
 			} else
-				strcpy(rindex(namebuf, '!')+1, cp);
+				strcpy(strrchr(namebuf, '!')+1, cp);
 			strcat(namebuf, "!");
 			goto newname;
 		}
@@ -644,7 +641,7 @@ anyof(s1, s2)
 {
 
 	while (*s1)
-		if (index(s2, *s1++))
+		if (strchr(s2, *s1++))
 			return 1;
 	return 0;
 }
@@ -670,7 +667,7 @@ copy(s1, s2)
 	register char *s1, *s2;
 {
 
-	while ((*s2++ = *s1++) != '\0')
+	while (*s2++ = *s1++)
 		;
 	return s2 - 1;
 }
