@@ -1,6 +1,3 @@
-/*	$OpenBSD: cmd1.c,v 1.5 1996/06/08 19:48:11 christos Exp $	*/
-/*	$NetBSD: cmd1.c,v 1.5 1996/06/08 19:48:11 christos Exp $	*/
-
 /*-
  * Copyright (c) 1980, 1993
  *	The Regents of the University of California.  All rights reserved.
@@ -35,11 +32,7 @@
  */
 
 #ifndef lint
-#if 0
 static char sccsid[] = "@(#)cmd1.c	8.1 (Berkeley) 6/6/93";
-#else
-static char rcsid[] = "$OpenBSD: cmd1.c,v 1.5 1996/06/08 19:48:11 christos Exp $";
-#endif
 #endif /* not lint */
 
 #include "rcv.h"
@@ -59,10 +52,9 @@ static char rcsid[] = "$OpenBSD: cmd1.c,v 1.5 1996/06/08 19:48:11 christos Exp $
 static int screen;
 
 int
-headers(v)
-	void *v;
+headers(msgvec)
+	int *msgvec;
 {
-	int *msgvec = v;
 	register int n, mesg, flag;
 	register struct message *mp;
 	int size;
@@ -101,10 +93,9 @@ headers(v)
  * Scroll to the next/previous screen
  */
 int
-scroll(v)
-	void *v;
+scroll(arg)
+	char arg[];
 {
-	char *arg = v;
 	register int s, size;
 	int cur[1];
 
@@ -156,10 +147,9 @@ screensize()
  * in the passed message list.
  */
 int
-from(v)
-	void *v;
+from(msgvec)
+	int *msgvec;
 {
-	int *msgvec = v;
 	register int *ip;
 
 	for (ip = msgvec; *ip != NULL; ip++)
@@ -221,8 +211,7 @@ printhead(mesg)
  * Print out the value of dot.
  */
 int
-pdot(v)
-	void *v;
+pdot()
 {
 	printf("%d\n", dot - &message[0] + 1);
 	return(0);
@@ -232,12 +221,11 @@ pdot(v)
  * Print out all the possible commands.
  */
 int
-pcmdlist(v)
-	void *v;
+pcmdlist()
 {
-	extern const struct cmd cmdtab[];
-	register const struct cmd *cp;
+	register struct cmd *cp;
 	register int cc;
+	extern struct cmd cmdtab[];
 
 	printf("Commands are:\n");
 	for (cc = 0, cp = cmdtab; cp->c_name != NULL; cp++) {
@@ -258,10 +246,9 @@ pcmdlist(v)
  * Paginate messages, honor ignored fields.
  */
 int
-more(v)
-	void *v;
+more(msgvec)
+	int *msgvec;
 {
-	int *msgvec = v;
 	return (type1(msgvec, 1, 1));
 }
 
@@ -269,10 +256,9 @@ more(v)
  * Paginate messages, even printing ignored fields.
  */
 int
-More(v)
-	void *v;
+More(msgvec)
+	int *msgvec;
 {
-	int *msgvec = v;
 
 	return (type1(msgvec, 0, 1));
 }
@@ -281,10 +267,9 @@ More(v)
  * Type out messages, honor ignored fields.
  */
 int
-type(v)
-	void *v;
+type(msgvec)
+	int *msgvec;
 {
-	int *msgvec = v;
 
 	return(type1(msgvec, 1, 0));
 }
@@ -293,10 +278,9 @@ type(v)
  * Type out messages, even printing ignored fields.
  */
 int
-Type(v)
-	void *v;
+Type(msgvec)
+	int *msgvec;
 {
-	int *msgvec = v;
 
 	return(type1(msgvec, 0, 0));
 }
@@ -311,15 +295,10 @@ type1(msgvec, doign, page)
 	int doign, page;
 {
 	register *ip;
-	struct message *mp;
-	char *cp;
+	register struct message *mp;
+	register char *cp;
 	int nlines;
 	FILE *obuf;
-#if __GNUC__
-	/* Avoid longjmp clobbering */
-	(void) &cp;
-	(void) &obuf;
-#endif
 
 	obuf = stdout;
 	if (setjmp(pipestop))
@@ -349,7 +328,7 @@ type1(msgvec, doign, page)
 		dot = mp;
 		if (value("quiet") == NOSTR)
 			fprintf(obuf, "Message %d:\n", *ip);
-		(void) send(mp, obuf, doign ? ignore : 0, NOSTR);
+		(void) sendmsg(mp, obuf, doign ? ignore : 0, NOSTR);
 	}
 close_pipe:
 	if (obuf != stdout) {
@@ -380,10 +359,9 @@ brokpipe(signo)
  * and defaults to 5.
  */
 int
-top(v)
-	void *v;
+top(msgvec)
+	int *msgvec;
 {
-	int *msgvec = v;
 	register int *ip;
 	register struct message *mp;
 	int c, topl, lines, lineb;
@@ -423,10 +401,9 @@ top(v)
  * get mboxed.
  */
 int
-stouch(v)
-	void *v;
+stouch(msgvec)
+	int msgvec[];
 {
-	int *msgvec = v;
 	register int *ip;
 
 	for (ip = msgvec; *ip != 0; ip++) {
@@ -441,10 +418,9 @@ stouch(v)
  * Make sure all passed messages get mboxed.
  */
 int
-mboxit(v)
-	void *v;
+mboxit(msgvec)
+	int msgvec[];
 {
-	int *msgvec = v;
 	register int *ip;
 
 	for (ip = msgvec; *ip != 0; ip++) {
@@ -459,8 +435,7 @@ mboxit(v)
  * List the folders the user currently has.
  */
 int
-folders(v)
-	void *v;
+folders()
 {
 	char dirname[BUFSIZ];
 	char *cmd;
