@@ -1,6 +1,3 @@
-/*	$OpenBSD: cmd2.c,v 1.5 1996/06/08 19:48:13 christos Exp $	*/
-/*	$NetBSD: cmd2.c,v 1.5 1996/06/08 19:48:13 christos Exp $	*/
-
 /*
  * Copyright (c) 1980, 1993
  *	The Regents of the University of California.  All rights reserved.
@@ -35,23 +32,19 @@
  */
 
 #ifndef lint
-#if 0
 static char sccsid[] = "@(#)cmd2.c	8.1 (Berkeley) 6/6/93";
-#else
-static char rcsid[] = "$OpenBSD: cmd2.c,v 1.5 1996/06/08 19:48:13 christos Exp $";
-#endif
 #endif /* not lint */
 
 #include "rcv.h"
 #include <sys/wait.h>
 #include "extern.h"
+#include "pwait.h"
 
 /*
  * Mail -- a mail program
  *
  * More user commands.
  */
-static int igcomp __P((const void *, const void *));
 
 /*
  * If any arguments were given, go to the next applicable argument
@@ -59,10 +52,9 @@ static int igcomp __P((const void *, const void *));
  * If given as first command with no arguments, print first message.
  */
 int
-next(v)
-	void *v;
+next(msgvec)
+	int *msgvec;
 {
-	int *msgvec = v;
 	register struct message *mp;
 	register int *ip, *ip2;
 	int list[2], mdot;
@@ -139,10 +131,9 @@ hitit:
  * so we can discard when the user quits.
  */
 int
-save(v)
-	void *v;
+save(str)
+	char str[];
 {
-	char *str = v;
 
 	return save1(str, 1, "save", saveignore);
 }
@@ -151,10 +142,9 @@ save(v)
  * Copy a message to a file without affected its saved-ness
  */
 int
-copycmd(v)
-	void *v;
+copycmd(str)
+	char str[];
 {
-	char *str = v;
 
 	return save1(str, 0, "copy", saveignore);
 }
@@ -204,7 +194,7 @@ save1(str, mark, cmd, ignore)
 	for (ip = msgvec; *ip && ip-msgvec < msgCount; ip++) {
 		mp = &message[*ip - 1];
 		touch(mp);
-		if (send(mp, obuf, ignore, NOSTR) < 0) {
+		if (sendmsg(mp, obuf, ignore, NOSTR) < 0) {
 			perror(file);
 			Fclose(obuf);
 			return(1);
@@ -225,10 +215,9 @@ save1(str, mark, cmd, ignore)
  * file name, minus header and trailing blank line.
  */
 int
-swrite(v)
-	void *v;
+swrite(str)
+	char str[];
 {
-	char *str = v;
 
 	return save1(str, 1, "write", ignoreall);
 }
@@ -281,10 +270,9 @@ snarf(linebuf, flag)
  * Delete messages.
  */
 int
-delete(v)
-	void *v;
+delete(msgvec)
+	int msgvec[];
 {
-	int *msgvec = v;
 	delm(msgvec);
 	return 0;
 }
@@ -293,10 +281,9 @@ delete(v)
  * Delete messages, then type the new dot.
  */
 int
-deltype(v)
-	void *v;
+deltype(msgvec)
+	int msgvec[];
 {
-	int *msgvec = v;
 	int list[2];
 	int lastdot;
 
@@ -359,10 +346,9 @@ delm(msgvec)
  * Undelete the indicated messages.
  */
 int
-undeletecmd(v)
-	void *v;
+undelete(msgvec)
+	int *msgvec;
 {
-	int *msgvec = v;
 	register struct message *mp;
 	register *ip;
 
@@ -379,11 +365,10 @@ undeletecmd(v)
  * Interactively dump core on "core"
  */
 int
-core(v)
-	void *v;
+core()
 {
 	int pid;
-	extern union wait wait_status;
+	extern wait_t wait_status;
 
 	switch (pid = vfork()) {
 	case -1:
@@ -396,7 +381,7 @@ core(v)
 	printf("Okie dokie");
 	fflush(stdout);
 	wait_child(pid);
-	if (wait_status.w_coredump)
+	if (WCOREDUMP(wait_status))
 		printf(" -- Core dumped.\n");
 	else
 		printf(" -- Can't dump core.\n");
@@ -407,10 +392,9 @@ core(v)
  * Clobber as many bytes of stack as the user requests.
  */
 int
-clobber(v)
-	void *v;
+clobber(argv)
+	char **argv;
 {
-	char **argv = v;
 	register int times;
 
 	if (argv[0] == 0)
@@ -443,10 +427,9 @@ clob1(n)
  * If no arguments, print the current list of retained fields.
  */
 int
-retfield(v)
-	void *v;
+retfield(list)
+	char *list[];
 {
-	char **list = v;
 
 	return ignore1(list, ignore + 1, "retained");
 }
@@ -456,28 +439,25 @@ retfield(v)
  * If no arguments, print the current list of ignored fields.
  */
 int
-igfield(v)
-	void *v;
+igfield(list)
+	char *list[];
 {
-	char **list = v;
 
 	return ignore1(list, ignore, "ignored");
 }
 
 int
-saveretfield(v)
-	void *v;
+saveretfield(list)
+	char *list[];
 {
-	char **list = v;
 
 	return ignore1(list, saveignore + 1, "retained");
 }
 
 int
-saveigfield(v)
-	void *v;
+saveigfield(list)
+	char *list[];
 {
-	char **list = v;
 
 	return ignore1(list, saveignore, "ignored");
 }
@@ -522,6 +502,7 @@ igshow(tab, which)
 	register int h;
 	struct ignore *igp;
 	char **ap, **ring;
+	int igcomp();
 
 	if (tab->i_count == 0) {
 		printf("No fields currently being %s.\n", which);
@@ -542,7 +523,7 @@ igshow(tab, which)
 /*
  * Compare two names for sorting ignored field list.
  */
-static int
+int
 igcomp(l, r)
 	const void *l, *r;
 {
