@@ -1,6 +1,3 @@
-/*	$OpenBSD: collect.c,v 1.6 1996/06/08 19:48:16 christos Exp $	*/
-/*	$NetBSD: collect.c,v 1.6 1996/06/08 19:48:16 christos Exp $	*/
-
 /*
  * Copyright (c) 1980, 1993
  *	The Regents of the University of California.  All rights reserved.
@@ -35,11 +32,7 @@
  */
 
 #ifndef lint
-#if 0
 static char sccsid[] = "@(#)collect.c	8.2 (Berkeley) 4/19/94";
-#else
-static char rcsid[] = "$OpenBSD: collect.c,v 1.6 1996/06/08 19:48:16 christos Exp $";
-#endif
 #endif /* not lint */
 
 /*
@@ -75,6 +68,8 @@ static	jmp_buf	colljmp;		/* To get back to work */
 static	int	colljmp_p;		/* whether to long jump */
 static	jmp_buf	collabort;		/* To end collection with error */
 
+static	char linebuf[LINESIZE];		/* To read a line of the message */
+
 FILE *
 collect(hp, printheaders)
 	struct header *hp;
@@ -83,26 +78,18 @@ collect(hp, printheaders)
 	FILE *fbuf;
 	int lc, cc, escape, eofcount;
 	register int c, t;
-	char linebuf[LINESIZE], *cp;
-	extern char *tempMail;
+	char *cp;
+	extern char tempMail[];
 	char getsub;
-	sigset_t oset, nset;
-#if __GNUC__
-	/* Avoid longjmp clobbering */
-	(void) &escape;
-	(void) &eofcount;
-	(void) &getsub;
-#endif
+	int omask;
+	void collint(), collhup(), collstop();
 
 	collf = NULL;
 	/*
 	 * Start catching signals from here, but we're still die on interrupts
 	 * until we're in the main loop.
 	 */
-	sigemptyset(&nset);
-	sigaddset(&nset, SIGINT);
-	sigaddset(&nset, SIGHUP);
-	sigprocmask(SIG_BLOCK, &nset, &oset);
+	omask = sigblock(sigmask(SIGINT) | sigmask(SIGHUP));
 	if ((saveint = signal(SIGINT, SIG_IGN)) != SIG_IGN)
 		signal(SIGINT, collint);
 	if ((savehup = signal(SIGHUP, SIG_IGN)) != SIG_IGN)
@@ -114,7 +101,7 @@ collect(hp, printheaders)
 		rm(tempMail);
 		goto err;
 	}
-	sigprocmask(SIG_SETMASK, &oset, NULL);
+	sigsetmask(omask & ~(sigmask(SIGINT) | sigmask(SIGHUP)));
 
 	noreset++;
 	if ((collf = Fopen(tempMail, "w+")) == NULL) {
@@ -205,7 +192,7 @@ cont:
 			/*
 			 * Dump core.
 			 */
-			core(NULL);
+			core();
 			break;
 		case '!':
 			/*
@@ -215,7 +202,6 @@ cont:
 			shell(&linebuf[2]);
 			break;
 		case ':':
-		case '_':
 			/*
 			 * Escape to command mode, but be nice!
 			 */
@@ -271,7 +257,6 @@ cont:
 			strcpy(linebuf + 2, getdeadletter());
 			/* fall into . . . */
 		case 'r':
-		case '<':
 			/*
 			 * Invoke a file:
 			 * Search for the file name,
@@ -389,16 +374,13 @@ out:
 	if (collf != NULL)
 		rewind(collf);
 	noreset--;
-	sigemptyset(&nset);
-	sigaddset(&nset, SIGINT);
-	sigaddset(&nset, SIGHUP);
-	sigprocmask(SIG_BLOCK, &nset, &oset);
+	sigblock(sigmask(SIGINT) | sigmask(SIGHUP));
 	signal(SIGINT, saveint);
 	signal(SIGHUP, savehup);
 	signal(SIGTSTP, savetstp);
 	signal(SIGTTOU, savettou);
 	signal(SIGTTIN, savettin);
-	sigprocmask(SIG_SETMASK, &oset, NULL);
+	sigsetmask(omask);
 	return collf;
 }
 
@@ -483,7 +465,7 @@ mespipe(fp, cmd)
 {
 	FILE *nf;
 	sig_t sigint = signal(SIGINT, SIG_IGN);
-	extern char *tempEdit;
+	extern char tempEdit[];
 	char *shell;
 
 	if ((nf = Fopen(tempEdit, "w+")) == NULL) {
@@ -532,7 +514,7 @@ forward(ms, fp, f)
 	int f;
 {
 	register int *msgvec;
-	extern char *tempMail;
+	extern char tempMail[];
 	struct ignoretab *ig;
 	char *tabst;
 
@@ -560,7 +542,7 @@ forward(ms, fp, f)
 
 		touch(mp);
 		printf(" %d", *msgvec);
-		if (send(mp, fp, ig, tabst) < 0) {
+		if (sendmsg(mp, fp, ig, tabst) < 0) {
 			perror(tempMail);
 			return(-1);
 		}
@@ -578,15 +560,20 @@ collstop(s)
 	int s;
 {
 	sig_t old_action = signal(s, SIG_DFL);
-	sigset_t nset;
 
-	sigemptyset(&nset);
-	sigaddset(&nset, s);
-	sigprocmask(SIG_UNBLOCK, &nset, NULL);
+	sigsetmask(sigblock(0) & ~sigmask(s));
 	kill(0, s);
-	sigprocmask(SIG_BLOCK, &nset, NULL);
+	sigblock(sigmask(s));
 	signal(s, old_action);
 	if (colljmp_p) {
+#ifdef __linux__
+/*  the signal was received in fgets().  Since the signal handler never
+ *  returns to let fgets() finish, stdin gets mildly confused, and the
+ *  next fgets call will return immediately with bad data.
+ *  we get that call out of the way here.
+ */
+		readline(stdin, linebuf, LINESIZE);
+#endif /* __linux__*/
 		colljmp_p = 0;
 		hadintr = 0;
 		longjmp(colljmp, 1);
@@ -612,6 +599,10 @@ collint(s)
 			clearerr(stdin);
 			return;
 		}
+#ifdef __linux__
+		/* see comment in collstop() */
+		readline(stdin, linebuf, LINESIZE);
+#endif /* __linux__*/
 		hadintr = 1;
 		longjmp(colljmp, 1);
 	}
