@@ -1,5 +1,3 @@
-/*	$OpenBSD: def.h,v 1.8 1996/06/08 19:48:18 christos Exp $	*/
-/*	$NetBSD: def.h,v 1.8 1996/06/08 19:48:18 christos Exp $	*/
 /*
  * Copyright (c) 1980, 1993
  *	The Regents of the University of California.  All rights reserved.
@@ -33,7 +31,6 @@
  * SUCH DAMAGE.
  *
  *	@(#)def.h	8.2 (Berkeley) 3/21/94
- *	$NetBSD: def.h,v 1.8 1996/06/08 19:48:18 christos Exp $
  */
 
 /*
@@ -43,16 +40,19 @@
  */
 
 #include <sys/param.h>
+#include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/time.h>
 
 #include <signal.h>
-#include <termios.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <ctype.h>
 #include <string.h>
+#if !(BSD == 43)
+#include <time.h>
+#endif
 #include "pathnames.h"
 
 #define	APPEND				/* New mail goes to end of mailbox */
@@ -93,6 +93,10 @@ struct message {
 #define	MSTATUS		(1<<9)		/* message status has changed */
 #define	MBOX		(1<<10)		/* Send this to mbox, regardless */
 
+#undef blockof
+#undef offsetof
+#undef positionof
+
 /*
  * Given a file address, determine the block number it represents.
  */
@@ -107,7 +111,7 @@ struct message {
  */
 struct cmd {
 	char	*c_name;		/* Name of command */
-	int	(*c_func) __P((void *));/* Implementor of the command */
+	int	(*c_func)();		/* Implementor of the command */
 	short	c_argtype;		/* Type of arglist (see below) */
 	short	c_msgflag;		/* Required flags of messages */
 	short	c_msgmask;		/* Relevant flags of messages */
@@ -275,5 +279,5 @@ struct ignoretab {
  */
 #define trunc(stream) {							\
 	(void)fflush(stream); 						\
-	(void)ftruncate(fileno(stream), (off_t)ftell(stream));		\
+	(void)ftruncate(fileno(stream), (long)ftell(stream));		\
 }
