@@ -1,6 +1,3 @@
-/*	$OpenBSD: fio.c,v 1.5 1996/06/08 19:48:22 christos Exp $	*/
-/*	$NetBSD: fio.c,v 1.5 1996/06/08 19:48:22 christos Exp $	*/
-
 /*
  * Copyright (c) 1980, 1993
  *	The Regents of the University of California.  All rights reserved.
@@ -35,21 +32,15 @@
  */
 
 #ifndef lint
-#if 0
 static char sccsid[] = "@(#)fio.c	8.1 (Berkeley) 6/6/93";
-#else
-static char rcsid[] = "$OpenBSD: fio.c,v 1.5 1996/06/08 19:48:22 christos Exp $";
-#endif
 #endif /* not lint */
 
 #include "rcv.h"
 #include <sys/file.h>
 #include <sys/wait.h>
-
-#include <unistd.h>
-#include <paths.h>
 #include <errno.h>
 #include "extern.h"
+#include "pwait.h"
 
 /*
  * Mail -- a mail program
@@ -128,7 +119,7 @@ setptr(ibuf)
 						;
 					if (cp[-1] != ':')
 						break;
-					while ((c = *cp++) != '\0')
+					while (c = *cp++)
 						if (c == 'R')
 							this.m_flag |= MREAD;
 						else if (c == 'O')
@@ -262,7 +253,7 @@ rm(name)
 }
 
 static int sigdepth;		/* depth of holdsigs() */
-static sigset_t nset, oset;
+static int omask;
 /*
  * Hold signals SIGHUP, SIGINT, and SIGQUIT.
  */
@@ -270,13 +261,8 @@ void
 holdsigs()
 {
 
-	if (sigdepth++ == 0) {
-		sigemptyset(&nset);
-		sigaddset(&nset, SIGHUP);
-		sigaddset(&nset, SIGINT);
-		sigaddset(&nset, SIGQUIT);
-		sigprocmask(SIG_BLOCK, &nset, &oset);
-	}
+	if (sigdepth++ == 0)
+		omask = sigblock(sigmask(SIGHUP)|sigmask(SIGINT)|sigmask(SIGQUIT));
 }
 
 /*
@@ -287,7 +273,7 @@ relsesigs()
 {
 
 	if (--sigdepth == 0)
-		sigprocmask(SIG_SETMASK, &oset, NULL);
+		sigsetmask(omask);
 }
 
 /*
@@ -309,6 +295,7 @@ fsize(iob)
  * Evaluate the string given as a new mailbox name.
  * Supported meta characters:
  *	%	for my system mail box
+ * 	%@	for my POP mail box
  *	%user	for user's system mail box
  *	#	for previous file
  *	&	invoker's mbox file
@@ -326,7 +313,7 @@ expand(name)
 	register char *cp, *shell;
 	int pivec[2];
 	struct stat sbuf;
-	extern union wait wait_status;
+	extern wait_t wait_status;
 
 	/*
 	 * The order of evaluation is "%" and "#" expand into constants.
@@ -336,6 +323,11 @@ expand(name)
 	 */
 	switch (*name) {
 	case '%':
+		if (name[1] == '@' && name[2] == '\0') {
+			if (! (name = value("POPBOX")))
+				name = "~/mbox.pop";
+			break;
+		}
 		findmail(name[1] ? name + 1 : myname, xname);
 		return savestr(xname);
 	case '#':
@@ -378,7 +370,7 @@ expand(name)
 	close(pivec[1]);
 	l = read(pivec[0], xname, BUFSIZ);
 	close(pivec[0]);
-	if (wait_child(pid) < 0 && wait_status.w_termsig != SIGPIPE) {
+	if (wait_child(pid) < 0 && WTERMSIG(wait_status) != SIGPIPE) {
 		fprintf(stderr, "\"%s\": Expansion failed.\n", name);
 		return NOSTR;
 	}
@@ -398,7 +390,7 @@ expand(name)
 	for (cp = &xname[l-1]; *cp == '\n' && cp > xname; cp--)
 		;
 	cp[1] = '\0';
-	if (index(xname, ' ') && stat(xname, &sbuf) < 0) {
+	if (strchr(xname, ' ') && stat(xname, &sbuf) < 0) {
 		fprintf(stderr, "\"%s\": Ambiguous.\n", name);
 		return NOSTR;
 	}
@@ -441,3 +433,14 @@ getdeadletter()
 	}
 	return cp;
 }
+
+#ifdef ultrix
+int
+mkstemp(template)
+	char *template;
+{
+	if (mktemp (template))
+		return (open (template, O_RDWR|O_CREAT|O_EXCL, 00666));
+	return (-1);
+}
+#endif
