@@ -1,6 +1,3 @@
-/*	$OpenBSD: lex.c,v 1.7 1996/06/08 19:48:28 christos Exp $	*/
-/*	$NetBSD: lex.c,v 1.7 1996/06/08 19:48:28 christos Exp $	*/
-
 /*
  * Copyright (c) 1980, 1993
  *	The Regents of the University of California.  All rights reserved.
@@ -35,11 +32,7 @@
  */
 
 #ifndef lint
-#if 0
 static char sccsid[] = "@(#)lex.c	8.1 (Berkeley) 6/6/93";
-#else
-static char rcsid[] = "$OpenBSD: lex.c,v 1.7 1996/06/08 19:48:28 christos Exp $";
-#endif
 #endif /* not lint */
 
 #include "rcv.h"
@@ -69,14 +62,25 @@ setfile(name)
 	int i;
 	struct stat stb;
 	char isedit = *name != '%';
-	char *who = name[1] ? name + 1 : myname;
+	char *who;
 	static int shudclob;
-	extern char *tempMesg;
+	extern char tempMesg[];
 	extern int errno;
 
+	/* %@ is for POP mailbox, so need to check for that */
+	if (name[1] && (name[1] != '@' || name[2]))
+		who = name + 1;
+	else
+		who = myname;
+
 	if ((name = expand(name)) == NOSTR)
 		return -1;
 
+	if (value("pop-mail")) {
+	     if (popmail_tofile(name, who))
+		  exit(1);
+	}
+
 	if ((ibuf = Fopen(name, "r")) == NULL) {
 		if (!isedit && errno == ENOENT)
 			goto nomail;
@@ -175,10 +179,7 @@ commands()
 	int eofloop = 0;
 	register int n;
 	char linebuf[LINESIZE];
-#if __GNUC__
-	/* Avoid longjmp clobbering */
-	(void) &eofloop;
-#endif
+	void intr(), stop(), hangup();
 
 	if (!sourcing) {
 		if (signal(SIGINT, SIG_IGN) != SIG_IGN)
@@ -256,7 +257,7 @@ execute(linebuf, contxt)
 {
 	char word[LINESIZE];
 	char *arglist[MAXARGC];
-	const struct cmd *com = NULL;
+	struct cmd *com;
 	register char *cp, *cp2;
 	register int c;
 	int muvec[2];
@@ -282,7 +283,7 @@ execute(linebuf, contxt)
 		return(0);
 	}
 	cp2 = word;
-	while (*cp && index(" \t0123456789$^.:/-+*'\"", *cp) == NOSTR)
+	while (*cp && strchr(" \t0123456789$^.:/-+*'\"", *cp) == NOSTR)
 		*cp2++ = *cp++;
 	*cp2 = '\0';
 
@@ -308,7 +309,7 @@ execute(linebuf, contxt)
 	 */
 
 	if ((com->c_argtype & F) == 0)
-		if ((cond == CRCV && !rcvmode) || (cond == CSEND && rcvmode))
+		if (cond == CRCV && !rcvmode || cond == CSEND && rcvmode)
 			return(0);
 
 	/*
@@ -431,8 +432,6 @@ out:
 			unstack();
 		return 0;
 	}
-	if (com == NULL)
-		return(0);
 	if (value("autoprint") != NOSTR && com->c_argtype & P)
 		if ((dot->m_flag & MDELETED) == 0) {
 			muvec[0] = dot - &message[0] + 1;
@@ -463,12 +462,12 @@ setmsize(sz)
  * to the passed command "word"
  */
 
-const struct cmd *
+struct cmd *
 lex(word)
 	char word[];
 {
-	extern const struct cmd cmdtab[];
-	register const struct cmd *cp;
+	register struct cmd *cp;
+	extern struct cmd cmdtab[];
 
 	for (cp = &cmdtab[0]; cp->c_name != NOSTR; cp++)
 		if (isprefix(word, cp->c_name))
@@ -535,13 +534,10 @@ stop(s)
 	int s;
 {
 	sig_t old_action = signal(s, SIG_DFL);
-	sigset_t nset;
 
-	sigemptyset(&nset);
-	sigaddset(&nset, s);
-	sigprocmask(SIG_UNBLOCK, &nset, NULL);
+	sigsetmask(sigblock(0) & ~sigmask(s));
 	kill(0, s);
-	sigprocmask(SIG_BLOCK, &nset, NULL);
+	sigblock(sigmask(s));
 	signal(s, old_action);
 	if (reset_on_stop) {
 		reset_on_stop = 0;
@@ -648,8 +644,8 @@ newfileinfo()
 
 /*ARGSUSED*/
 int
-pversion(v)
-	void *v;
+pversion(e)
+	int e;
 {
 	extern char *version;
 
