@@ -1,6 +1,3 @@
-/*	$OpenBSD: main.c,v 1.5 1996/06/08 19:48:31 christos Exp $	*/
-/*	$NetBSD: main.c,v 1.5 1996/06/08 19:48:31 christos Exp $	*/
-
 /*
  * Copyright (c) 1980, 1993
  *	The Regents of the University of California.  All rights reserved.
@@ -41,18 +38,23 @@ static char copyright[] =
 #endif /* not lint */
 
 #ifndef lint
-#if 0
 static char sccsid[] = "@(#)main.c	8.1 (Berkeley) 6/6/93";
-#else
-static char rcsid[] = "$OpenBSD: main.c,v 1.5 1996/06/08 19:48:31 christos Exp $";
-#endif
 #endif /* not lint */
 
 #include "rcv.h"
 #include <fcntl.h>
-#include <sys/ioctl.h>
 #include "extern.h"
 
+#ifdef linux 
+#define B1200 9
+#define B9600 13
+#else
+#include <sgtty.h> /* for B1200 */
+#endif
+
+extern int optind;
+extern char *optarg;
+
 /*
  * Mail -- a mail program
  *
@@ -70,8 +72,24 @@ main(argc, argv)
 	struct name *to, *cc, *bcc, *smopts;
 	char *subject;
 	char *ef;
-	char nosrc = 0;
+	char nosrc = 0, forcepop = 0;
+	void hdrstop();
 	sig_t prevint;
+	void sigchild();
+
+        /*
+         * Absolutely the first thing we do is save our egid
+         * and set it to the rgid, so that we can safely run
+         * setgid.  We use the sgid (saved set-gid) to allow ourselves
+         * to revert to the egid if we want (temporarily) to become
+         * priveliged.
+         */
+        effectivegid = getegid();
+        realgid = getgid();
+        if (setgid (realgid) < 0) {
+		perror("setgid");
+		exit(1);
+	}
 
 	/*
 	 * Set up a reasonable environment.
@@ -95,7 +113,7 @@ main(argc, argv)
 	bcc = NIL;
 	smopts = NIL;
 	subject = NOSTR;
-	while ((i = getopt(argc, argv, "INT:b:c:dfins:u:v")) != EOF) {
+	while ((i = getopt(argc, argv, "INT:b:c:dfins:u:vpP")) != EOF) {
 		switch (i) {
 		case 'T':
 			/*
@@ -183,12 +201,24 @@ main(argc, argv)
 			 */
 			bcc = cat(bcc, nalloc(optarg, GBCC));
 			break;
+		case 'p':
+			/*
+			 * Turn on pop mode.
+			 */
+			forcepop = 1;
+			break;
+		case 'P':
+			/*
+			 * Turn off pop mode.
+			 */
+			forcepop = 2;
+			break;
 		case '?':
 			fputs("\
 Usage: mail [-iInv] [-s subject] [-c cc-addr] [-b bcc-addr] to-addr ...\n\
             [- sendmail-options ...]\n\
-       mail [-iInNv] -f [name]\n\
-       mail [-iInNv] [-u user]\n",
+       mail [-pPiInNv] -f [name]\n\
+       mail [-pPiInNv] [-u user]\n",
 				stderr);
 			exit(1);
 		}
@@ -227,6 +257,40 @@ Usage: mail [-iInv] [-s subject] [-c cc-addr] [-b bcc-addr] to-addr ...\n\
 		 */
 		exit(senderr);
 	}
+#ifdef POP_DEFAULT
+	assign("pop-mail", "");
+#endif
+	/*
+	 * If the user has explicitly requested that pop be enabled or
+	 * disabled on the command line, set or unset the pop-mail as
+	 * appropriate.
+	 */
+	if (forcepop == 1) {
+		assign("pop-mail", "");
+	}
+	else if (forcepop == 2) {
+		if (value("pop-mail")) {
+			char *arglist[2];
+			arglist[0] = "pop-mail";
+			arglist[1] = 0;
+			unset(arglist);
+		}
+	}
+	/*
+	 * Now, if pop-mail is defined, and ef == NOSTR, set ef to the
+	 * user's mailbox and call the function to append new pop mail
+	 * to the end of it before continuing.
+	 */
+	if (value("pop-mail")) {
+		if (! ef)
+			ef = "%@";
+		else {
+			char *arglist[2];
+			arglist[0] = "pop-mail";
+			arglist[1] = 0;
+			unset(arglist);
+		}
+	}
 	/*
 	 * Ok, we are reading mail.
 	 * Decide whether we are editing a mailbox or reading
@@ -280,26 +344,16 @@ hdrstop(signo)
 void
 setscreensize()
 {
-	struct termios tbuf;
-	struct winsize ws;
-	speed_t ospeed;
+	int col, row, baud;
 
-	if (ioctl(1, TIOCGWINSZ, (char *) &ws) < 0)
-		ws.ws_col = ws.ws_row = 0;
-	if (tcgetattr(1, &tbuf) < 0)
-		ospeed = 9600;
-	else
-		ospeed = cfgetospeed(&tbuf);
-	if (ospeed < 1200)
-		screenheight = 9;
-	else if (ospeed == 1200)
-		screenheight = 14;
-	else if (ws.ws_row != 0)
-		screenheight = ws.ws_row;
-	else
-		screenheight = 24;
-	if ((realscreenheight = ws.ws_row) == 0)
-		realscreenheight = 24;
-	if ((screenwidth = ws.ws_col) == 0)
-		screenwidth = 80;
+	if (getscreensize (&col, &row) < 0) {
+		col = 80;
+		row = 24;
+	}
+	if ((baud = getbaudrate ()) < 0)
+		baud = B9600;
+
+	realscreenheight = row;
+	screenheight = (baud < B1200 ? 9 : (baud == B1200 ? 14 : row));
+	screenwidth = col;
 }
