@@ -1,6 +1,3 @@
-/*	$OpenBSD: popen.c,v 1.3 1996/06/26 21:22:34 dm Exp $	*/
-/*	$NetBSD: popen.c,v 1.4 1996/06/08 19:48:35 christos Exp $	*/
-
 /*
  * Copyright (c) 1980, 1993
  *	The Regents of the University of California.  All rights reserved.
@@ -35,17 +32,14 @@
  */
 
 #ifndef lint
-#if 0
 static char sccsid[] = "@(#)popen.c	8.1 (Berkeley) 6/6/93";
-#else
-static char rcsid[] = "$OpenBSD: popen.c,v 1.3 1996/06/26 21:22:34 dm Exp $";
-#endif
 #endif /* not lint */
 
 #include "rcv.h"
 #include <sys/wait.h>
 #include <fcntl.h>
 #include "extern.h"
+#include "pwait.h"
 
 #define READ 0
 #define WRITE 1
@@ -62,13 +56,12 @@ struct child {
 	int pid;
 	char done;
 	char free;
-	union wait status;
+	wait_t status;
 	struct child *link;
 };
 static struct child *child;
 static struct child *findchild __P((int));
 static void delchild __P((struct child *));
-static int file_pid __P((FILE *));
 
 FILE *
 Fopen(file, mode)
@@ -113,7 +106,6 @@ Popen(cmd, mode)
 	int p[2];
 	int myside, hisside, fd0, fd1;
 	int pid;
-	sigset_t nset;
 	FILE *fp;
 
 	if (pipe(p) < 0)
@@ -129,8 +121,7 @@ Popen(cmd, mode)
 		hisside = fd0 = p[READ];
 		fd1 = -1;
 	}
-	sigemptyset(&nset);
-	if ((pid = start_command(cmd, &nset, fd0, fd1, NOSTR, NOSTR, NOSTR)) < 0) {
+	if ((pid = start_command(cmd, 0, fd0, fd1, NOSTR, NOSTR, NOSTR)) < 0) {
 		close(p[READ]);
 		close(p[WRITE]);
 		return NULL;
@@ -146,17 +137,14 @@ Pclose(ptr)
 	FILE *ptr;
 {
 	int i;
-	sigset_t nset, oset;
+	int omask;
 
 	i = file_pid(ptr);
 	unregister_file(ptr);
 	(void) fclose(ptr);
-	sigemptyset(&nset);
-	sigaddset(&nset, SIGINT);
-	sigaddset(&nset, SIGHUP);
-	sigprocmask(SIG_BLOCK, &nset, &oset);
+	omask = sigblock(sigmask(SIGINT)|sigmask(SIGHUP));
 	i = wait_child(i);
-	sigprocmask(SIG_SETMASK, &oset, NULL);
+	sigsetmask(omask);
 	return i;
 }
 
@@ -193,7 +181,7 @@ unregister_file(fp)
 {
 	struct fp **pp, *p;
 
-	for (pp = &fp_head; (p = *pp) != NULL; pp = &p->link)
+	for (pp = &fp_head; p = *pp; pp = &p->link)
 		if (p->fp == fp) {
 			*pp = p->link;
 			free((char *) p);
@@ -202,7 +190,6 @@ unregister_file(fp)
 	panic("Invalid file pointer");
 }
 
-static int
 file_pid(fp)
 	FILE *fp;
 {
@@ -226,8 +213,7 @@ file_pid(fp)
 int
 run_command(cmd, mask, infd, outfd, a0, a1, a2)
 	char *cmd;
-	sigset_t *mask;
-	int infd, outfd;
+	int mask, infd, outfd;
 	char *a0, *a1, *a2;
 {
 	int pid;
@@ -241,8 +227,7 @@ run_command(cmd, mask, infd, outfd, a0, a1, a2)
 int
 start_command(cmd, mask, infd, outfd, a0, a1, a2)
 	char *cmd;
-	sigset_t *mask;
-	int infd, outfd;
+	int mask, infd, outfd;
 	char *a0, *a1, *a2;
 {
 	int pid;
@@ -268,12 +253,10 @@ start_command(cmd, mask, infd, outfd, a0, a1, a2)
 }
 
 void
-prepare_child(nset, infd, outfd)
-	sigset_t *nset;
-	int infd, outfd;
+prepare_child(mask, infd, outfd)
+	int mask, infd, outfd;
 {
 	int i;
-	sigset_t fset;
 
 	/*
 	 * All file descriptors other than 0, 1, and 2 are supposed to be
@@ -283,15 +266,12 @@ prepare_child(nset, infd, outfd)
 		dup2(infd, 0);
 	if (outfd >= 0)
 		dup2(outfd, 1);
-	if (nset) {
-		for (i = 1; i <= NSIG; i++)
-			if (sigismember(nset, i))
-				(void) signal(i, SIG_IGN);
-		if (!sigismember(nset, SIGINT))
-			(void) signal(SIGINT, SIG_DFL);
-	}
-	sigfillset(&fset);
-	(void) sigprocmask(SIG_UNBLOCK, &fset, NULL);
+	for (i = 1; i <= NSIG; i++)
+		if (mask & sigmask(i))
+			(void) signal(i, SIG_IGN);
+	if ((mask & sigmask(SIGINT)) == 0)
+		(void) signal(SIGINT, SIG_DFL);
+	(void) sigsetmask(0);
 }
 
 int
@@ -341,7 +321,7 @@ sigchild(signo)
 	int signo;
 {
 	int pid;
-	union wait status;
+	wait_t status;
 	register struct child *cp;
 
 	while ((pid =
@@ -356,7 +336,7 @@ sigchild(signo)
 	}
 }
 
-union wait wait_status;
+wait_t wait_status;
 
 /*
  * Wait for a specific child to die.
@@ -365,18 +345,15 @@ int
 wait_child(pid)
 	int pid;
 {
-	sigset_t nset, oset;
+	int mask = sigblock(sigmask(SIGCHLD));
 	register struct child *cp = findchild(pid);
-	sigemptyset(&nset);
-	sigaddset(&nset, SIGCHLD);
-	sigprocmask(SIG_BLOCK, &nset, &oset);
 
 	while (!cp->done)
-		sigsuspend(&oset);
+		sigpause(mask);
 	wait_status = cp->status;
 	delchild(cp);
-	sigprocmask(SIG_SETMASK, &oset, NULL);
-	return wait_status.w_status ? -1 : 0;
+	sigsetmask(mask);
+	return WEXITSTATUS(wait_status) ? -1 : 0;
 }
 
 /*
@@ -386,15 +363,12 @@ void
 free_child(pid)
 	int pid;
 {
-	sigset_t nset, oset;
+	int mask = sigblock(sigmask(SIGCHLD));
 	register struct child *cp = findchild(pid);
-	sigemptyset(&nset);
-	sigaddset(&nset, SIGCHLD);
-	sigprocmask(SIG_BLOCK, &nset, &oset);
 
 	if (cp->done)
 		delchild(cp);
 	else
 		cp->free = 1;
-	sigprocmask(SIG_SETMASK, &oset, NULL);
+	sigsetmask(mask);
 }
