@@ -1,6 +1,3 @@
-/*	$OpenBSD: quit.c,v 1.5 1996/06/08 19:48:37 christos Exp $	*/
-/*	$NetBSD: quit.c,v 1.5 1996/06/08 19:48:37 christos Exp $	*/
-
 /*
  * Copyright (c) 1980, 1993
  *	The Regents of the University of California.  All rights reserved.
@@ -35,14 +32,11 @@
  */
 
 #ifndef lint
-#if 0
 static char sccsid[] = "@(#)quit.c	8.1 (Berkeley) 6/6/93";
-#else
-static char rcsid[] = "$OpenBSD: quit.c,v 1.5 1996/06/08 19:48:37 christos Exp $";
-#endif
 #endif /* not lint */
 
 #include "rcv.h"
+#include <sys/file.h>
 #include <fcntl.h>
 #include "extern.h"
 
@@ -56,8 +50,7 @@ static char rcsid[] = "$OpenBSD: quit.c,v 1.5 1996/06/08 19:48:37 christos Exp $
  * The "quit" command.
  */
 int
-quitcmd(v)
-	void *v;
+quitcmd()
 {
 	/*
 	 * If we are sourcing, then return 1 so execute() can handle it.
@@ -77,10 +70,10 @@ void
 quit()
 {
 	int mcount, p, modify, autohold, anystat, holdbit, nohold;
-	FILE *ibuf = NULL, *obuf, *fbuf, *rbuf, *readstat = NULL, *abuf;
+	FILE *ibuf, *obuf, *fbuf, *rbuf, *readstat, *abuf;
 	register struct message *mp;
 	register int c;
-	extern char *tempQuit, *tempResid;
+	extern char tempQuit[], tempResid[];
 	struct stat minfo;
 	char *mbox;
 
@@ -109,17 +102,12 @@ quit()
 	 * a message.
 	 */
 
+	if (lock_name(mailname) < 0)
+		return;
 	fbuf = Fopen(mailname, "r");
 	if (fbuf == NULL)
 		goto newmail;
-	if (flock(fileno(fbuf), LOCK_EX) == -1) {
-nolock:
-		perror("Unable to lock mailbox");
-		Fclose(fbuf);
-		return;
-	}
-	if (dot_lock(mailname, 1, stdout, ".") == -1)
-		goto nolock;
+	flock(fileno(fbuf), LOCK_EX);
 	rbuf = NULL;
 	if (fstat(fileno(fbuf), &minfo) >= 0 && minfo.st_size > mailsize) {
 		printf("New mail has arrived.\n");
@@ -191,16 +179,12 @@ nolock:
 	if (p == msgCount && !modify && !anystat) {
 		printf("Held %d message%s in %s\n",
 			p, p == 1 ? "" : "s", mailname);
-		Fclose(fbuf);
-		dot_unlock(mailname);
-		return;
+		goto done;
 	}
 	if (c == 0) {
 		if (p != 0) {
 			writeback(rbuf);
-			Fclose(fbuf);
-			dot_unlock(mailname);
-			return;
+			goto done;
 		}
 		goto cream;
 	}
@@ -217,17 +201,13 @@ nolock:
 	if (value("append") == NOSTR) {
 		if ((obuf = Fopen(tempQuit, "w")) == NULL) {
 			perror(tempQuit);
-			Fclose(fbuf);
-			dot_unlock(mailname);
-			return;
+			goto done;
 		}
 		if ((ibuf = Fopen(tempQuit, "r")) == NULL) {
 			perror(tempQuit);
 			rm(tempQuit);
 			Fclose(obuf);
-			Fclose(fbuf);
-			dot_unlock(mailname);
-			return;
+			goto done;
 		}
 		rm(tempQuit);
 		if ((abuf = Fopen(mbox, "r")) != NULL) {
@@ -239,38 +219,30 @@ nolock:
 			perror(tempQuit);
 			Fclose(ibuf);
 			Fclose(obuf);
-			Fclose(fbuf);
-			dot_unlock(mailname);
-			return;
+			goto done;
 		}
 		Fclose(obuf);
 		close(creat(mbox, 0600));
 		if ((obuf = Fopen(mbox, "r+")) == NULL) {
 			perror(mbox);
 			Fclose(ibuf);
-			Fclose(fbuf);
-			dot_unlock(mailname);
-			return;
+			goto done;
 		}
 	}
-	else {
+	if (value("append") != NOSTR) {
 		if ((obuf = Fopen(mbox, "a")) == NULL) {
 			perror(mbox);
-			Fclose(fbuf);
-			dot_unlock(mailname);
-			return;
+			goto done;
 		}
 		fchmod(fileno(obuf), 0600);
 	}
 	for (mp = &message[0]; mp < &message[msgCount]; mp++)
 		if (mp->m_flag & MBOX)
-			if (send(mp, obuf, saveignore, NOSTR) < 0) {
+			if (sendmsg(mp, obuf, saveignore, NOSTR) < 0) {
 				perror(mbox);
 				Fclose(ibuf);
 				Fclose(obuf);
-				Fclose(fbuf);
-				dot_unlock(mailname);
-				return;
+				goto done;
 			}
 
 	/*
@@ -295,9 +267,7 @@ nolock:
 	if (ferror(obuf)) {
 		perror(mbox);
 		Fclose(obuf);
-		Fclose(fbuf);
-		dot_unlock(mailname);
-		return;
+		goto done;
 	}
 	Fclose(obuf);
 	if (mcount == 1)
@@ -312,9 +282,7 @@ nolock:
 
 	if (p != 0) {
 		writeback(rbuf);
-		Fclose(fbuf);
-		dot_unlock(mailname);
-		return;
+		goto done;
 	}
 
 	/*
@@ -333,21 +301,17 @@ cream:
 		trunc(abuf);
 		Fclose(abuf);
 		alter(mailname);
-		Fclose(fbuf);
-		dot_unlock(mailname);
-		return;
+		goto done;
 	}
 	demail();
-	Fclose(fbuf);
-	dot_unlock(mailname);
-	return;
+	goto done;
 
 newmail:
 	printf("Thou hast new mail.\n");
-	if (fbuf != NULL) {
+done:
+	if (fbuf != NULL)
 		Fclose(fbuf);
-		dot_unlock(mailname);
-	}
+	unlock_name(mailname);
 }
 
 /*
@@ -377,7 +341,7 @@ writeback(res)
 	for (mp = &message[0]; mp < &message[msgCount]; mp++)
 		if ((mp->m_flag&MPRESERVE)||(mp->m_flag&MTOUCH)==0) {
 			p++;
-			if (send(mp, obuf, (struct ignoretab *)0, NOSTR) < 0) {
+			if (sendmsg(mp, obuf, (struct ignoretab *)0, NOSTR) < 0) {
 				perror(mailname);
 				Fclose(obuf);
 				return(-1);
@@ -416,9 +380,10 @@ edstop()
 	extern char *tmpdir;
 	register int gotcha, c;
 	register struct message *mp;
-	FILE *obuf, *ibuf, *readstat = NULL;
+	FILE *obuf, *ibuf, *readstat;
 	struct stat statb;
-	char *tempname;
+	char tempname[30];
+	char *mktemp();
 
 	if (readonly)
 		return;
@@ -447,8 +412,9 @@ edstop()
 		goto done;
 	ibuf = NULL;
 	if (stat(mailname, &statb) >= 0 && statb.st_size > mailsize) {
-		tempname = tempnam(tmpdir, "mbox");
-
+		strcpy(tempname, tmpdir);
+		strcat(tempname, "mboxXXXXXX");
+		mktemp(tempname);
 		if ((obuf = Fopen(tempname, "w")) == NULL) {
 			perror(tempname);
 			relsesigs();
@@ -473,7 +439,6 @@ edstop()
 			reset(0);
 		}
 		rm(tempname);
-		free(tempname);
 	}
 	printf("\"%s\" ", mailname);
 	fflush(stdout);
@@ -488,7 +453,7 @@ edstop()
 		if ((mp->m_flag & MDELETED) != 0)
 			continue;
 		c++;
-		if (send(mp, obuf, (struct ignoretab *) NULL, NOSTR) < 0) {
+		if (sendmsg(mp, obuf, (struct ignoretab *) NULL, NOSTR) < 0) {
 			perror(mailname);
 			relsesigs();
 			reset(0);
