@@ -1,6 +1,3 @@
-/*	$OpenBSD: temp.c,v 1.5 1996/06/08 19:48:42 christos Exp $	*/
-/*	$NetBSD: temp.c,v 1.5 1996/06/08 19:48:42 christos Exp $	*/
-
 /*
  * Copyright (c) 1980, 1993
  *	The Regents of the University of California.  All rights reserved.
@@ -35,11 +32,7 @@
  */
 
 #ifndef lint
-#if 0
 static char sccsid[] = "@(#)temp.c	8.1 (Berkeley) 6/6/93";
-#else
-static char rcsid[] = "$OpenBSD: temp.c,v 1.5 1996/06/08 19:48:42 christos Exp $";
-#endif
 #endif /* not lint */
 
 #include "rcv.h"
@@ -52,27 +45,43 @@ static char rcsid[] = "$OpenBSD: temp.c,v 1.5 1996/06/08 19:48:42 christos Exp $
  * Give names to all the temporary files that we will need.
  */
 
-char	*tempMail;
-char	*tempQuit;
-char	*tempEdit;
-char	*tempResid;
-char	*tempMesg;
+char	tempMail[24];
+char	tempQuit[24];
+char	tempEdit[24];
+char	tempResid[24];
+char	tempMesg[24];
 char	*tmpdir;
 
 void
 tinit()
 {
 	register char *cp;
+	int len;
 
-	if ((tmpdir = getenv("TMPDIR")) == NULL) {
+	if ((tmpdir = getenv("TMPDIR")) == NULL)
 		tmpdir = _PATH_TMP;
+	else {
+		len = strlen(tmpdir);
+		if ((cp = malloc(len + 2)) == NULL) {
+			(void)perror("mail");
+			exit (1);
+		}
+		(void)strcpy(cp, tmpdir);
+		cp[len] = '/';
+		cp[len + 1] = '\0';
+		tmpdir = cp;
 	}
-
-	tempMail  = tempnam (tmpdir, "Rs");
-	tempResid = tempnam (tmpdir, "Rq");
-	tempQuit  = tempnam (tmpdir, "Rm");
-	tempEdit  = tempnam (tmpdir, "Re");
-	tempMesg  = tempnam (tmpdir, "Rx");
+			
+	strcpy(tempMail, tmpdir);
+	mktemp(strcat(tempMail, "RsXXXXXX"));
+	strcpy(tempResid, tmpdir);
+	mktemp(strcat(tempResid, "RqXXXXXX"));
+	strcpy(tempQuit, tmpdir);
+	mktemp(strcat(tempQuit, "RmXXXXXX"));
+	strcpy(tempEdit, tmpdir);
+	mktemp(strcat(tempEdit, "ReXXXXXX"));
+	strcpy(tempMesg, tmpdir);
+	mktemp(strcat(tempMesg, "RxXXXXXX"));
 
 	/*
 	 * It's okay to call savestr in here because main will
@@ -86,9 +95,11 @@ tinit()
 		}
 	} else {
 		if ((cp = username()) == NOSTR) {
-			myname = "nobody";
-			if (rcvmode)
+			myname = "ubluit";
+			if (rcvmode) {
+				printf("Who are you!?\n");
 				exit(1);
+			}
 		} else
 			myname = savestr(cp);
 	}
