@@ -1,6 +1,3 @@
-/*	$OpenBSD: tty.c,v 1.5 1996/06/08 19:48:43 christos Exp $	*/
-/*	$NetBSD: tty.c,v 1.5 1996/06/08 19:48:43 christos Exp $	*/
-
 /*
  * Copyright (c) 1980, 1993
  *	The Regents of the University of California.  All rights reserved.
@@ -35,11 +32,7 @@
  */
 
 #ifndef lint
-#if 0
 static char sccsid[] = "@(#)tty.c	8.1 (Berkeley) 6/6/93";
-#else
-static char rcsid[] = "$OpenBSD: tty.c,v 1.5 1996/06/08 19:48:43 christos Exp $";
-#endif
 #endif /* not lint */
 
 /*
@@ -50,10 +43,13 @@ static char rcsid[] = "$OpenBSD: tty.c,v 1.5 1996/06/08 19:48:43 christos Exp $"
 
 #include "rcv.h"
 #include "extern.h"
-#include <sys/ioctl.h>
-
-static	cc_t	c_erase;		/* Current erase char */
-static	cc_t	c_kill;			/* Current kill char */
+#ifdef linux
+#include <bsd/sgtty.h>
+#else
+#include <sgtty.h>
+#endif
+static	int	c_erase;		/* Current erase char */
+static	int	c_kill;			/* Current kill char */
 static	jmp_buf	rewrite;		/* Place to go when continued */
 static	jmp_buf	intjmp;			/* Place to go when interrupted */
 #ifndef TIOCSTI
@@ -69,7 +65,7 @@ grabh(hp, gflags)
 	struct header *hp;
 	int gflags;
 {
-	struct termios ttybuf;
+	struct sgttyb ttybuf;
 	sig_t saveint;
 #ifndef TIOCSTI
 	sig_t savequit;
@@ -78,10 +74,7 @@ grabh(hp, gflags)
 	sig_t savettou;
 	sig_t savettin;
 	int errs;
-#ifdef __GNUC__
-	/* Avoid longjmp clobbering */
-	(void) &saveint;
-#endif
+	void ttyint();
 
 	savetstp = signal(SIGTSTP, SIG_DFL);
 	savettou = signal(SIGTTOU, SIG_DFL);
@@ -90,15 +83,15 @@ grabh(hp, gflags)
 #ifndef TIOCSTI
 	ttyset = 0;
 #endif
-	if (tcgetattr(fileno(stdin), &ttybuf) < 0) {
-		perror("tcgetattr");
+	if (ioctl(fileno(stdin), TIOCGETP, &ttybuf) < 0) {
+		perror("gtty");
 		return(-1);
 	}
-	c_erase = ttybuf.c_cc[VERASE];
-	c_kill = ttybuf.c_cc[VKILL];
+	c_erase = ttybuf.sg_erase;
+	c_kill = ttybuf.sg_kill;
 #ifndef TIOCSTI
-	ttybuf.c_cc[VERASE] = 0;
-	ttybuf.c_cc[VKILL] = 0;
+	ttybuf.sg_erase = 0;
+	ttybuf.sg_kill = 0;
 	if ((saveint = signal(SIGINT, SIG_IGN)) == SIG_DFL)
 		signal(SIGINT, SIG_DFL);
 	if ((savequit = signal(SIGQUIT, SIG_IGN)) == SIG_DFL)
@@ -111,7 +104,7 @@ grabh(hp, gflags)
 	if (gflags & GTO) {
 #ifndef TIOCSTI
 		if (!ttyset && hp->h_to != NIL)
-			ttyset++, tcsetattr(fileno(stdin), TCSADRAIN, &ttybuf);
+			ttyset++, stty(fileno(stdin), &ttybuf);
 #endif
 		hp->h_to =
 			extract(readtty("To: ", detract(hp->h_to, 0)), GTO);
@@ -119,14 +112,14 @@ grabh(hp, gflags)
 	if (gflags & GSUBJECT) {
 #ifndef TIOCSTI
 		if (!ttyset && hp->h_subject != NOSTR)
-			ttyset++, tcsetattr(fileno(stdin), TCSADRAIN, &ttybuf);
+			ttyset++, stty(fileno(stdin), &ttybuf);
 #endif
 		hp->h_subject = readtty("Subject: ", hp->h_subject);
 	}
 	if (gflags & GCC) {
 #ifndef TIOCSTI
 		if (!ttyset && hp->h_cc != NIL)
-			ttyset++, tcsetattr(fileno(stdin), TCSADRAIN, &ttybuf);
+			ttyset++, stty(fileno(stdin), &ttybuf);
 #endif
 		hp->h_cc =
 			extract(readtty("Cc: ", detract(hp->h_cc, 0)), GCC);
@@ -134,7 +127,7 @@ grabh(hp, gflags)
 	if (gflags & GBCC) {
 #ifndef TIOCSTI
 		if (!ttyset && hp->h_bcc != NIL)
-			ttyset++, tcsetattr(fileno(stdin), TCSADRAIN, &ttybuf);
+			ttyset++, stty(fileno(stdin), &ttybuf);
 #endif
 		hp->h_bcc =
 			extract(readtty("Bcc: ", detract(hp->h_bcc, 0)), GBCC);
@@ -144,10 +137,10 @@ out:
 	signal(SIGTTOU, savettou);
 	signal(SIGTTIN, savettin);
 #ifndef TIOCSTI
-	ttybuf.c_cc[VERASE] = c_erase;
-	ttybuf.c_cc[VKILL] = c_kill;
+	ttybuf.sg_erase = c_erase;
+	ttybuf.sg_kill = c_kill;
 	if (ttyset)
-		tcsetattr(fileno(stdin), TCSADRAIN, &ttybuf);
+		stty(fileno(stdin), &ttybuf);
 	signal(SIGQUIT, savequit);
 #endif
 	signal(SIGINT, saveint);
@@ -167,12 +160,8 @@ readtty(pr, src)
 {
 	char ch, canonb[BUFSIZ];
 	int c;
-	char *cp, *cp2;
-#if __GNUC__
-	/* Avoid longjmp clobbering */
-	(void) &c;
-	(void) &cp2;
-#endif
+	register char *cp, *cp2;
+	void ttystop();
 
 	fputs(pr, stdout);
 	fflush(stdout);
@@ -189,9 +178,8 @@ readtty(pr, src)
 	fflush(stdout);
 #else
 	cp = src == NOSTR ? "" : src;
-	while ((c = *cp++) != '\0') {
-		if ((c_erase != _POSIX_VDISABLE && c == c_erase) ||
-		    (c_kill != _POSIX_VDISABLE && c == c_kill)) {
+	while (c = *cp++) {
+		if (c == c_erase || c == c_kill) {
 			ch = '\\';
 			ioctl(0, TIOCSTI, &ch);
 		}
@@ -235,7 +223,7 @@ redo:
 		return(strlen(canonb) > 0 ? savestr(canonb) : NOSTR);
 	while (*cp != '\0') {
 		c = *cp++;
-		if (c_erase != _POSIX_VDISABLE && c == c_erase) {
+		if (c == c_erase) {
 			if (cp2 == canonb)
 				continue;
 			if (cp2[-1] == '\\') {
@@ -245,7 +233,7 @@ redo:
 			cp2--;
 			continue;
 		}
-		if (c_kill != _POSIX_VDISABLE && c == c_kill) {
+		if (c == c_kill) {
 			if (cp2 == canonb)
 				continue;
 			if (cp2[-1] == '\\') {
@@ -272,13 +260,10 @@ ttystop(s)
 	int s;
 {
 	sig_t old_action = signal(s, SIG_DFL);
-	sigset_t nset;
 
-	sigemptyset(&nset);
-	sigaddset(&nset, s);
-	sigprocmask(SIG_BLOCK, &nset, NULL);
+	sigsetmask(sigblock(0) & ~sigmask(s));
 	kill(0, s);
-	sigprocmask(SIG_UNBLOCK, &nset, NULL);
+	sigblock(sigmask(s));
 	signal(s, old_action);
 	longjmp(rewrite, 1);
 }
@@ -290,3 +275,32 @@ ttyint(s)
 {
 	longjmp(intjmp, 1);
 }
+
+int
+getscreensize(colp, rowp)
+	int *colp;
+	int *rowp;
+{
+	struct winsize ws;
+
+	if (ioctl(1, TIOCGWINSZ, (char *) &ws) < 0) {
+		*colp = *rowp = 0;
+		return (-1);
+	}
+	if (ws.ws_col <= 0 || ws.ws_row <= 0) {
+		return (-1);
+	}
+	*colp = ws.ws_col;
+	*rowp = ws.ws_row;
+	return (0);
+}
+
+int
+getbaudrate()
+{
+	struct sgttyb tbuf;
+
+	if (ioctl(1, TIOCGETP, &tbuf) < 0)
+		return (-1);
+	return (tbuf.sg_ospeed);
+}
