@@ -1,6 +1,3 @@
-/*	$OpenBSD: version.c,v 1.4 1996/06/08 19:48:46 christos Exp $	*/
-/*	$NetBSD: version.c,v 1.4 1996/06/08 19:48:46 christos Exp $	*/
-
 /*
  * Copyright (c) 1980, 1993
  *	The Regents of the University of California.  All rights reserved.
@@ -35,15 +32,11 @@
  */
 
 #ifndef lint
-#if 0
 static char sccsid[] = "@(#)version.c	8.1 (Berkeley) 6/6/93";
-#else
-static char rcsid[] = "$OpenBSD: version.c,v 1.4 1996/06/08 19:48:46 christos Exp $";
-#endif
 #endif /* not lint */
 
 /*
  * Just keep track of the date/sid of this version of Mail.
  * Load this file first to get a "total" Mail version.
  */
-char	*version = "8.1 6/6/93";
+char	*version = "8.1 6/6/93 (POP extension)";
